@@ -27,10 +27,11 @@ use crate::commissions::CommissionCalc;
 use crate::core::{EmptyResult, GenericResult};
 use crate::currency::{Cash, CashAssets, MultiCurrencyCashAccount};
 use crate::currency::converter::CurrencyConverter;
+use crate::exchanges::Exchanges;
 use crate::formatting;
 use crate::instruments::{InstrumentInternalIds, InstrumentInfo};
 use crate::localities;
-use crate::quotes::Quotes;
+use crate::quotes::{Quotes, QuoteQuery};
 use crate::taxes::TaxRemapping;
 use crate::time::{self, Date, DateOptTime, Period};
 use crate::types::{Decimal, TradeType};
@@ -68,6 +69,7 @@ pub struct BrokerStatement {
     pub idle_cash_interest: Vec<IdleCashInterest>,
     pub tax_agent_withholdings: Vec<TaxWithholding>,
 
+    pub exchanges: Exchanges,
     pub forex_trades: Vec<ForexTrade>,
     pub stock_buys: Vec<StockBuy>,
     pub stock_sells: Vec<StockSell>,
@@ -192,6 +194,7 @@ impl BrokerStatement {
             idle_cash_interest: Vec::new(),
             tax_agent_withholdings: Vec::new(),
 
+            exchanges: Exchanges::new_empty(),
             forex_trades: Vec::new(),
             stock_buys: Vec::new(),
             stock_sells: Vec::new(),
@@ -241,18 +244,27 @@ impl BrokerStatement {
 
     pub fn batch_quotes(&self, quotes: &Quotes) -> EmptyResult {
         for symbol in self.open_positions.keys() {
-            quotes.batch(symbol)?;
+            quotes.batch(self.get_quote_query(symbol))?;
         }
         Ok(())
     }
 
+    pub fn get_quote_query(&self, symbol: &str) -> QuoteQuery {
+        let exchanges = match self.instrument_info.get(symbol) {
+            Some(instrument) if !instrument.exchanges.is_empty() => &instrument.exchanges,
+            _ => &self.exchanges,
+        };
+        QuoteQuery::Stock(symbol.to_owned(), exchanges.get_prioritized())
+    }
+
     pub fn net_value(&self, converter: &CurrencyConverter, quotes: &Quotes, currency: &str) -> GenericResult<Cash> {
         self.batch_quotes(quotes)?;
 
         let mut net_value = self.cash_assets.total_assets_real_time(currency, converter)?;
 
         for (symbol, quantity) in &self.open_positions {
-            let price = converter.real_time_convert_to(quotes.get(symbol)?, currency)?;
+            let price = quotes.get(self.get_quote_query(symbol))?;
+            let price = converter.real_time_convert_to(price, currency)?;
             net_value += quantity * price;
         }
 
@@ -421,6 +433,7 @@ impl BrokerStatement {
         self.idle_cash_interest.extend(statement.idle_cash_interest.into_iter());
         self.tax_agent_withholdings.extend(statement.tax_agent_withholdings.into_iter());
 
+        self.exchanges.merge(statement.exchanges);
         self.forex_trades.extend(statement.forex_trades.into_iter());
         self.stock_buys.extend(statement.stock_buys.into_iter());
         self.stock_sells.extend(statement.stock_sells.into_iter());
