@@ -1,7 +1,6 @@
 #[cfg(test)] use crate::commissions::CommissionCalc;
 use crate::commissions::{CommissionSpec, CommissionSpecBuilder, CumulativeCommissionSpecBuilder};
-#[cfg(test)] use crate::currency::{Cash, MultiCurrencyCashAccount};
-#[cfg(test)] use crate::currency::converter::CurrencyConverter;
+#[cfg(test)] use crate::currency::{Cash, converter::CurrencyConverter};
 #[cfg(test)] use crate::types::TradeType;
 use crate::util::RoundingMethod;
 
@@ -60,7 +59,7 @@ mod tests {
         let currency = "RUB";
         let converter = CurrencyConverter::mock();
         let mut calc = CommissionCalc::new(
-            converter, super::investor(), Cash::new(currency, dec!(0))).unwrap();
+            converter, super::investor(), Cash::zero(currency)).unwrap();
 
         for &(date, shares, price) in &[
             (date!(2020, 10, 13),  28, dec!(1639.9)),
@@ -79,13 +78,13 @@ mod tests {
         ] {
             assert_eq!(
                 calc.add_trade(date, trade_type, shares.into(), Cash::new(currency, price)).unwrap(),
-                Cash::new(currency, dec!(0)),
+                Cash::zero(currency),
             );
         }
 
         assert_eq!(calc.calculate().unwrap(), hashmap!{
-            date!(2020, 10, 13) => MultiCurrencyCashAccount::new_from(Cash::new(currency, dec!(599.83))),
-            date!(2020, 10, 14) => MultiCurrencyCashAccount::new_from(Cash::new(currency, dec!(  0.48))),
+            date!(2020, 10, 13) => Cash::new(currency, dec!(599.83)).into(),
+            date!(2020, 10, 14) => Cash::new(currency, dec!(  0.48)).into(),
         });
     }
 
@@ -111,15 +110,15 @@ mod tests {
         ] {
             assert_eq!(
                 calc.add_trade(date, trade_type, shares.into(), Cash::new(currency, price)).unwrap(),
-                Cash::new(currency, dec!(0)),
+                Cash::zero(currency),
             );
         }
 
         assert_eq!(calc.calculate().unwrap(), hashmap!{
-            date!(2020, 10, 13) => MultiCurrencyCashAccount::new_from(Cash::new(currency, dec!(99.97) + dec!(349.89))),
-            date!(2020, 10, 14) => MultiCurrencyCashAccount::new_from(Cash::new(currency, dec!(0.05) + dec!(0.17))),
+            date!(2020, 10, 13) => Cash::new(currency, dec!(99.97) + dec!(349.89)).into(),
+            date!(2020, 10, 14) => Cash::new(currency, dec!(0.05) + dec!(0.17)).into(),
             // Actually we have different date, but use fist day of the next month for simplicity
-            date!(2020, 11,  1) => MultiCurrencyCashAccount::new_from(Cash::new(currency, dec!(299))),
+            date!(2020, 11,  1) => Cash::new(currency, dec!(299)).into(),
         });
     }
 
@@ -128,7 +127,7 @@ mod tests {
         let currency = "RUB";
         let converter = CurrencyConverter::mock();
         let mut calc = CommissionCalc::new(
-            converter, super::professional(), Cash::new(currency, dec!(0))).unwrap();
+            converter, super::professional(), Cash::zero(currency)).unwrap();
 
         for &(date, shares, price) in &[
             (date!(2019, 12, 2),  35, dec!(2959.5)),
@@ -138,19 +137,19 @@ mod tests {
         ] {
             assert_eq!(
                 calc.add_trade(date, trade_type, shares.into(), Cash::new(currency, price)).unwrap(),
-                Cash::new(currency, dec!(0)),
+                Cash::zero(currency),
             );
         }
 
         assert_eq!(calc.calculate().unwrap(), hashmap!{
-            date!(2019, 12, 2) => MultiCurrencyCashAccount::new_from(Cash::new(currency, dec!(68.45) + dec!(16.57))),
-            date!(2019, 12, 3) => MultiCurrencyCashAccount::new_from(Cash::new(currency, dec!(44.45) + dec!(8.37))),
+            date!(2019, 12, 2) => Cash::new(currency, dec!(68.45) + dec!(16.57)).into(),
+            date!(2019, 12, 3) => Cash::new(currency, dec!(44.45) + dec!(8.37)).into(),
 
             // Actually we have different date, but use fist day of the next month for simplicity
-            date!(2020, 1, 1) => MultiCurrencyCashAccount::new_from(Cash::new(currency,
+            date!(2020, 1, 1) => Cash::new(currency,
                 dec!(64.10) + // Monthly minimum
                 dec!(177) // Monthly depositary
-            )),
+            ).into(),
         });
     }
 }
\ No newline at end of file
