@@ -4,8 +4,7 @@
 use crate::commissions::{
     CommissionSpec, CommissionSpecBuilder, TradeCommissionSpecBuilder,
     TransactionCommissionSpecBuilder, CumulativeCommissionSpecBuilder};
-#[cfg(test)] use crate::currency::{Cash, MultiCurrencyCashAccount};
-#[cfg(test)] use crate::currency::converter::CurrencyConverter;
+#[cfg(test)] use crate::currency::{Cash, converter::CurrencyConverter};
 #[cfg(test)] use crate::types::TradeType;
 
 pub fn all_inclusive() -> CommissionSpec {
@@ -43,7 +42,7 @@ mod tests {
         let currency = "RUB";
         let converter = CurrencyConverter::mock();
         let mut calc = CommissionCalc::new(
-            converter, super::all_inclusive(), Cash::new(currency, dec!(0))).unwrap();
+            converter, super::all_inclusive(), Cash::zero(currency)).unwrap();
 
         let date = date!(2021, 1, 4);
 
@@ -68,7 +67,7 @@ mod tests {
         let currency = "RUB";
         let converter = CurrencyConverter::mock();
         let mut calc = CommissionCalc::new(
-            converter, super::iia(), Cash::new(currency, dec!(0))).unwrap();
+            converter, super::iia(), Cash::zero(currency)).unwrap();
 
         let date = date!(2017, 12, 14);
 
@@ -87,7 +86,7 @@ mod tests {
         assert_eq!(calc.calculate().unwrap(), hashmap!{
             // Depositary commission
             // Actually we have different date, but use fist day of the next month for simplicity
-            date!(2018, 1, 1) => MultiCurrencyCashAccount::new_from(Cash::new(currency, dec!(175))),
+            date!(2018, 1, 1) => Cash::new(currency, dec!(175)).into(),
         });
     }
 }
\ No newline at end of file
