@@ -9,6 +9,7 @@ use serde::Deserialize;
 use serde::de::Deserializer;
 
 use crate::core::{GenericResult, EmptyResult};
+use crate::exchanges::Exchanges;
 use crate::localities::Jurisdiction;
 
 #[derive(Clone, PartialEq, Eq, Hash, Debug)]
@@ -86,22 +87,18 @@ impl InstrumentInfo {
 
     pub fn add(&mut self, symbol: &str) -> GenericResult<&mut Instrument> {
         match self.instruments.entry(symbol.to_owned()) {
-            Entry::Vacant(entry) => Ok(entry.insert(Instrument {
-                symbol: symbol.to_owned(),
-                name:   None,
-                isin:   HashSet::new(),
-            })),
+            Entry::Vacant(entry) => Ok(entry.insert(Instrument::new(symbol))),
             Entry::Occupied(_) => Err!("Duplicated security symbol: {}", symbol),
         }
     }
 
+    pub fn get(&self, symbol: &str) -> Option<&Instrument> {
+        self.instruments.get(symbol)
+    }
+
     pub fn get_or_add(&mut self, symbol: &str) -> &mut Instrument {
         match self.instruments.entry(symbol.to_owned()) {
-            Entry::Vacant(entry) => entry.insert(Instrument {
-                symbol: symbol.to_owned(),
-                name:   None,
-                isin:   HashSet::new(),
-            }),
+            Entry::Vacant(entry) => entry.insert(Instrument::new(symbol)),
             Entry::Occupied(entry) => entry.into_mut(),
         }
     }
@@ -188,9 +185,19 @@ pub struct Instrument {
     pub symbol: String,
     name: Option<String>,
     pub isin: HashSet<String>,
+    pub exchanges: Exchanges,
 }
 
 impl Instrument {
+    fn new(symbol: &str) -> Instrument {
+        Instrument {
+            symbol:    symbol.to_owned(),
+            name:      None,
+            isin:      HashSet::new(),
+            exchanges: Exchanges::new_empty(),
+        }
+    }
+
     pub fn set_name(&mut self, name: &str) {
         self.name.replace(name.to_owned());
     }
@@ -248,6 +255,7 @@ impl Instrument {
             self.name.replace(name);
         }
         self.isin.extend(other.isin);
+        self.exchanges.merge(other.exchanges);
     }
 }
 
