@@ -22,7 +22,7 @@ pub fn generate_tax_statement(
     let broker = portfolio.broker.get_info(config, portfolio.plan.as_ref())?;
 
     let broker_statement = BrokerStatement::read(
-        broker, &portfolio.statements, &portfolio.symbol_remapping, &portfolio.instrument_internal_ids,
+        broker, portfolio.statements_path()?, &portfolio.symbol_remapping, &portfolio.instrument_internal_ids,
         &portfolio.instrument_names, portfolio.get_tax_remapping()?, &portfolio.corporate_actions,
         ReadingStrictness::TRADE_SETTLE_DATE)?;
 
