@@ -153,7 +153,7 @@ impl<'a> TradesProcessor<'a> {
 
     fn process_trades(&mut self, mut tax_statement: Option<&'a mut TaxStatement>) -> EmptyResult {
         let mut fees = self.pre_process_fees()?;
-        let jurisdiction = self.broker_statement.broker.type_.jurisdiction();
+        let broker_jurisdiction = self.broker_statement.broker.type_.jurisdiction();
 
         let mut trade_id = 0;
 
@@ -180,16 +180,19 @@ impl<'a> TradesProcessor<'a> {
             trade_id += 1;
 
             if let Some(ref mut statement) = tax_statement {
-                if jurisdiction == Jurisdiction::Usa {
-                    let tax_year_stat = self.tax_year_stat.get_mut(&tax_year).unwrap();
-                    let additional_fees = tax_year_stat.deductible_fees.take().unwrap_or_default();
-                    self.add_income(statement, trade, &details, additional_fees)?;
-                } else {
-                    warn!(concat!(
-                        "Tax statement generation for income from trading is supported only for brokers with USA jurisdiction. ",
-                        "Don't adding it to the tax statement."
-                    ));
-                    tax_statement = None;
+                match broker_jurisdiction {
+                    Jurisdiction::Usa => {
+                        let tax_year_stat = self.tax_year_stat.get_mut(&tax_year).unwrap();
+                        let additional_fees = tax_year_stat.deductible_fees.take().unwrap_or_default();
+                        self.add_income(statement, trade, &details, additional_fees)?;
+                    },
+                    Jurisdiction::Russia => {
+                        warn!(concat!(
+                            "Don't declare income from trading in the tax statement ",
+                            "assuming that it will be declared by broker's tax agent.",
+                        ));
+                        tax_statement = None;
+                    }
                 }
             }
         }
@@ -202,7 +205,7 @@ impl<'a> TradesProcessor<'a> {
     }
 
     fn process_trade(&mut self, trade_id: usize, trade: &StockSell, details: &SellDetails) -> EmptyResult {
-        let security = self.broker_statement.get_instrument_name(&trade.original_symbol);
+        let security = self.broker_statement.instrument_info.get_name(&trade.original_symbol);
         let (price, commission) = match trade.type_ {
             StockSellType::Trade {price, commission, ..} => (price, commission),
             _ => unreachable!(),
@@ -281,7 +284,7 @@ impl<'a> TradesProcessor<'a> {
     fn process_fifo(
         &mut self, trade_id: usize, trade: &FifoDetails, sell_execution_date: Date, first: bool,
     ) -> EmptyResult {
-        let security = self.broker_statement.get_instrument_name(&trade.original_symbol);
+        let security = self.broker_statement.instrument_info.get_name(&trade.original_symbol);
         self.stock_splits |= trade.multiplier != dec!(1);
 
         let mut execution_date_cell = None;
@@ -376,7 +379,7 @@ impl<'a> TradesProcessor<'a> {
         assert_eq!(details.taxable_local_profit, details.local_profit);
         assert!(details.fifo.iter().all(|trade| trade.long_term_ownership_deductible.is_none()));
 
-        let name = self.broker_statement.get_instrument_name(&trade.original_symbol);
+        let name = self.broker_statement.instrument_info.get_name(&trade.original_symbol);
         let description = format!("{}: Продажа {}", self.broker_statement.broker.name, name);
 
         let cost = details.total_local_cost.amount + additional_fees;
